# Bayesian analysis of differences between proportions
# Experiment 1 of decoy study
# Pierre Dragicevic

# # ---> To run this code, first install JAGS on your computer: https://sourceforge.net/projects/mcmc-jags/files/JAGS/4.x/
# # Then install the following R packages:
# install.packages('rjags', dependencies=T)
# install.packages('BEST', dependencies=T)

rm(list=ls())
library('BEST')

# no decoy (table)
table_nd1 <- 37
table_nd2 <- 17

# decoy on cleanliness (table)
table_dc1 <- 32
table_dc2 <- 19

# decoy on variety (table)
table_dv1 <- 24
table_dv2 <- 26

# no decoy (plot)
plot_nd1 <- 26
plot_nd2 <- 21

# decoy on cleanliness (plot)
plot_dc1 <- 39
plot_dc2 <- 14

# decoy on variety (plot)
plot_dv1 <- 26
plot_dv2 <- 24

bayesianAnalysis <- function(nd1, nd2, dc1, dc2, dv1, dv2) {
  
  # Use Jeffrey's non-informative prior (Beta distribution with a = 0.5, b = 0.5).
  # See, e.g., Zhu, Mu, and Arthur Y. Lu. "The counter-intuitive non-informative prior for the Bernoulli family." Journal of Statistics Education 12.2 (2004): 1-10. http://www.amstat.org/publications/jse/v12n2/zhu.pdf
  prior_a <- prior_b <- 0.5
  
  # Number of samples for simulations
  N <- 1e6
  
  # Update the beta distribution.
  # See, e.g., Chap 8 of Bolstad, William M. Introduction to Bayesian statistics. John Wiley & Sons, 2013. http://homepage.ntu.edu.tw/~ntucbsc/%A5%CD%AA%AB%C2%E5%BE%C7%B2%CE%ADp%BF%D4%B8%DF%A4@971008/[3]%20Chapter%208.pdf
  nd <- rbeta(N, shape1 = prior_a + nd1, shape2 = prior_b + nd2)
  dc <- rbeta(N, shape1 = prior_a + dc1, shape2 = prior_b + dc2)
  dv <- rbeta(N, shape1 = prior_a + dv1, shape2 = prior_b + dv2)
  diff <- dc - dv
  
  # Plot the posterior probability distribution
  hist(diff, freq=FALSE, xlim=c(-0.5, 0.5), ylim=c(0, 5), breaks=100)
  
  # Compute the highest density interval (HDI)
  hdiMC <- hdi(diff, credMass = 0.95)
  segments(hdiMC[1], 0, hdiMC[2], 0, lwd=5, col='red')
  cat('The 95% highest-density interval (HDI) for the combined attraction effect is', hdiMC * 100, '\n')
  
  # Compute posterior probabilities
  equiv <- 0.01 # Practical equivalence of +/- 1% 
  p_attraction <- sum(diff > equiv) / length(diff)
  p_repulsion <- sum(diff < equiv) / length(diff)
  p_null <- sum(diff >= -equiv & diff <= equiv) / length(diff)
  cat('The probability of a negligible (± 1%) effect is p =', p_null, '\n')
  cat('The probability of an attraction effect is p =', p_attraction, '\n')
  cat('The probability of a repulsion effect is p =', p_repulsion, '\n')
  cat('Ignoring previous studies and considering our data only, the presence of an attraction effect is', round(p_attraction / p_null), 'times more likely than a practically null effect, and', round(p_attraction / p_repulsion), 'times more likely than a repulsion effect.\n')
}

par(mfrow=c(2,1))
cat('\n\n#### Table ####\n')
bayesianAnalysis(table_nd1, table_nd2, table_dc1, table_dc2, table_dv1, table_dv2)
cat('\n\n#### Plot ####\n')
bayesianAnalysis(plot_nd1, plot_nd2, plot_dc1, plot_dc2, plot_dv1, plot_dv2)