#
# Computation and graphing of CIs for decoy/attraction experiments
# Pierre Dragicevic, Jan 2016
#

# Several helper functionns have been put in a separate R file for legibility. Execute the code here.
source('decoyCIsFunctions.R')

#
# Some parameters of the report
#
reportCumulatedAttractionEffects <- TRUE
reportAverageAttractionEffects <- FALSE
sigDigits <- NA # Use NA for a somehow 'clever' use of significant digits
plotRange <- c(-.6, .6)

###############
# Malkoc, 2013
###############

# Malkoc's frequency data copied from Anthi's email 13 Jan 2015, itself taken from
# (Malkoc et al, 2013) 

malkoc.no_decoy.cleanliness <- 32
malkoc.no_decoy.variety <- 17

malkoc.decoy_cleanliness.cleanliness <- 40
malkoc.decoy_cleanliness.variety <- 8

malkoc.decoy_variety.cleanliness <- 20
malkoc.decoy_variety.variety <- 30

###############
# Experiment 1
###############

# Frequency data copied from Anthi's Google Doc
# https://docs.google.com/document/d/1F5BE8V6OAxItZtl_5AkDQ4_wk2CD0OfQvhMkLG72Y_M/edit

table.no_decoy.cleanliness <- 37
table.no_decoy.variety <- 17

table.decoy_cleanliness.cleanliness <- 32
table.decoy_cleanliness.variety <- 19

table.decoy_variety.cleanliness <- 24
table.decoy_variety.variety <- 26

plot.no_decoy.cleanliness <- 26
plot.no_decoy.variety <- 21

plot.decoy_cleanliness.cleanliness <- 39
plot.decoy_cleanliness.variety <- 14

plot.decoy_variety.cleanliness <- 26
plot.decoy_variety.variety <- 24

###############
# Experiment 2
###############

# Frequency data copied from Anthi's email 13 Jan 2015

house.decoy_price.price <- 88
house.decoy_price.size <- 29

house.decoy_size.price <- 89
house.decoy_size.size <- 25

car.decoy_efficiency.efficiency <- 86
car.decoy_efficiency.power <- 30

car.decoy_power.efficiency <- 90
car.decoy_power.power <- 25

###############
# Experiment 3
###############

# Observations copied from http://evanthiadimara.com/experiment3/participants/statistics

bet.attraction.scores <- c(0.1, 0, -0.1, -0.2, -0.2, -0.25, 0.7, 0.2, 0.1, 0.1, 0.2, -0.2, 0.4, 0.2, 0.25, -0.1, -0.2, -0.2, 0, 1, 0.1, 0.1, 0.1, 0.1, 0.3, 0.4, 0, 0, 0, -0.1, 0, -0.1, 0.4, 0.2, 0.1, 0.1, 0.1, 0.2, -0.1, 0, 0.4, 0.05, 0.3, 0.35, 0.1, 0.35, 0.6, 0.1, -0.1, 0.1, 0, -0.2, 0.3, 0.25, 0.2, 0.1, 0.4, 0.1, 0.8, 0.4, -0.1, 0.2, 0.2, -0.1, 0.25, 0.6, 0.5, -0.1, 0.15, -0.1, 0.9, 0.4, 0.1)

# Within-pair consistency
bet.strategy.scores <- c(0.9, 0.8, 0.9, 0.8, 0.6, 0.65, 0.3, 0.8, 0.9, 0.9, 0.4, 0.8, 0.6, 0.8, 0.65, 0.9, 0.8, 0.6, 0.8, 0, 0.5, 0.9, 0.5, 0.9, 0.7, 0.6, 0.8, 0.6, 0.8, 0.5, 0.8, 0.7, 0.6, 0.8, 0.9, 0.9, 0.9, 0.8, 0.7, 1, 0.6, 0.95, 0.5, 0.65, 0.9, 0.45, 0.4, 0.7, 0.9, 0.7, 0.8, 0.6, 0.5, 0.25, 0.8, 0.9, 0.6, 0.9, 0.2, 0.6, 0.9, 0.6, 0.8, 0.9, 0.75, 0.2, 0.5, 0.7, 0.85, 0.7, 0.1, 0.4, 0.9)

# bet.decoy_prize.probability <- 482 + 7/2
# bet.decoy_prize.prize <- 241 + 7/2
# 
# bet.decoy_probability.probability <- 589 + 17/2
# bet.decoy_probability.prize <- 124 + 17/2

bet.decoy_prize.probability <- 482 + 7/2
bet.decoy_prize.prize <- 241 + 7/2

bet.decoy_probability.probability <- 589 + 17/2
bet.decoy_probability.prize <- 124 + 17/2

wedell.decoy_prize.probability <- 379 + 5/2
wedell.decoy_prize.prize <- 256 + 5/2

wedell.decoy_probability.probability <- 474 + 5/2
wedell.decoy_probability.prize <- 161 + 15/2


###############
# Analysis
###############

#
# 1. Double-check participant counts for safety (and compare with Anthi's email 13 Jan 2015)
#

cat("\n\n")

total_participants_1 <- table.no_decoy.cleanliness + table.no_decoy.variety + table.decoy_cleanliness.cleanliness + table.decoy_cleanliness.variety + table.decoy_variety.cleanliness + table.decoy_variety.variety + plot.no_decoy.cleanliness + plot.no_decoy.variety + plot.decoy_cleanliness.cleanliness + plot.decoy_cleanliness.variety + plot.decoy_variety.cleanliness + plot.decoy_variety.variety
cat("Total participants in experiment 1: ", total_participants_1, " (should be 305)\n")

total_participants_2 <- (house.decoy_price.price + house.decoy_price.size + house.decoy_size.price + house.decoy_size.size + car.decoy_efficiency.efficiency + car.decoy_efficiency.power + car.decoy_power.efficiency + car.decoy_power.power) / 2
cat("Total participants in experiment 2: ", total_participants_2, " (should be 231)\n")

total_participants_3 <- length(bet.attraction.scores)
cat("Total participants in experiment 3: ", total_participants_3, " (should be 73)\n")

#
# 2. Prepare the 'results' table and declare functions to add effects of interest as new rows of the table
#

# The data frame that will contains all data + methods to add new rows
results <- data.frame(label = character(0), point = numeric(0), ci.lower = numeric(0), ci.upper = numeric(0))

# Add a difference between proportions as a result
add.prop.diff <- function(results, label, x1, x2, y1, y2, multiply = 1) {
  diff_prop_ci <- diffpropCI(x1, x1 + x2, y1, y1 + y2) * multiply
  cat(pad(label, -32), format_ci(diff_prop_ci, sigdigits=sigDigits, width=result_width, percent=TRUE), "\n", sep='')
  rbind(results, data.frame(label = label, point = diff_prop_ci[1], ci.lower = diff_prop_ci[2], ci.upper = diff_prop_ci[3]))
}

# Add a sample mean as a result
add.mean <- function(results, label, obs, multiply = 1, percent_output = FALSE) {
  mean_ci <- meanCI(obs) * multiply
  cat(pad(label, -32), format_ci(mean_ci, sigdigits=sigDigits, width=result_width, percent=percent_output), "\n", sep='')
  rbind(results, data.frame(label = label, point = mean_ci[1], ci.lower = mean_ci[2], ci.upper = mean_ci[3]))
}

# Estimate the required width for the results column, for cleaner text output
result_width <- ifelse(is.na(sigDigits), 22, 22 + (sigDigits - 2) * 3)

cat("\n")

#
# 3. Compute and add all effects of interest to the 'results' table
#

## Effects for Malkoc

results <- add.prop.diff(
  results,
  'Malkoc, decoy on cleanliness',
  malkoc.decoy_cleanliness.cleanliness,
  malkoc.decoy_cleanliness.variety,
  malkoc.no_decoy.cleanliness,
  malkoc.no_decoy.variety
)

results <- add.prop.diff(
  results,
  'Malkoc, decoy on variety',
  malkoc.decoy_variety.variety,
  malkoc.decoy_variety.cleanliness,
  malkoc.no_decoy.variety,
  malkoc.no_decoy.cleanliness
)

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  'Malkoc, cumulated attraction',
  malkoc.decoy_variety.variety,
  malkoc.decoy_variety.cleanliness,
  malkoc.decoy_cleanliness.variety,
  malkoc.decoy_cleanliness.cleanliness,
  multiply = 1.0
)

if (reportAverageAttractionEffects) results <- add.prop.diff(
  results,
  'Malkoc, average attraction',
  malkoc.decoy_variety.variety,
  malkoc.decoy_variety.cleanliness,
  malkoc.decoy_cleanliness.variety,
  malkoc.decoy_cleanliness.cleanliness,
  multiply = 0.5
)

## Effects for experiment 1, table condition

results <- add.prop.diff(
  results,
  'Table, decoy on cleanliness',
  table.decoy_cleanliness.cleanliness,
  table.decoy_cleanliness.variety,
  table.no_decoy.cleanliness,
  table.no_decoy.variety
)

results <- add.prop.diff(
  results,
  'Table, decoy on variety',
  table.decoy_variety.variety,
  table.decoy_variety.cleanliness,
  table.no_decoy.variety,
  table.no_decoy.cleanliness
)

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  'Table, cumulated attraction',
  table.decoy_variety.variety,
  table.decoy_variety.cleanliness,
  table.decoy_cleanliness.variety,
  table.decoy_cleanliness.cleanliness,
  multiply = 1.0
)

if (reportAverageAttractionEffects) results <- add.prop.diff(
  results,
   'Table, average attraction',
   table.decoy_variety.variety,
   table.decoy_variety.cleanliness,
   table.decoy_cleanliness.variety,
   table.decoy_cleanliness.cleanliness,
   multiply = 0.5
)

## Effects for experiment 1, scatterplot condition

results <- add.prop.diff(
  results,
  'Plot, decoy on cleanliness',
  plot.decoy_cleanliness.cleanliness,
  plot.decoy_cleanliness.variety,
  plot.no_decoy.cleanliness,
  plot.no_decoy.variety
)

results <- add.prop.diff(
  results,
  'Plot, decoy on variety',
  plot.decoy_variety.variety,
  plot.decoy_variety.cleanliness,
  plot.no_decoy.variety,
  plot.no_decoy.cleanliness
)

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  'Plot, cumulated attraction',
  plot.decoy_variety.variety,
  plot.decoy_variety.cleanliness,
  plot.decoy_cleanliness.variety,
  plot.decoy_cleanliness.cleanliness,
  multiply = 1.0
)

if (reportAverageAttractionEffects) results <- add.prop.diff(
  results,
  'Plot, average attraction',
  plot.decoy_variety.variety,
  plot.decoy_variety.cleanliness,
  plot.decoy_cleanliness.variety,
  plot.decoy_cleanliness.cleanliness,
  multiply = 0.5
)

## Effects for experiment 2

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  'Houses, cumulated attraction',
  house.decoy_size.size,
  house.decoy_size.price,
  house.decoy_price.size,
  house.decoy_price.price,
  multiply = 1.0
)

if (reportAverageAttractionEffects) results <- add.prop.diff(
  results,
  'Houses, average attraction',
  house.decoy_size.size,
  house.decoy_size.price,
  house.decoy_price.size,
  house.decoy_price.price,
  multiply = 0.5
)

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  'Cars, cumulated attraction',
  car.decoy_power.power,
  car.decoy_power.efficiency,
  car.decoy_efficiency.power,
  car.decoy_efficiency.efficiency,
  multiply = 1.0
)

if (reportAverageAttractionEffects) results <- add.prop.diff(
  results,
  'Cars, average attraction',
  car.decoy_power.power,
  car.decoy_power.efficiency,
  car.decoy_efficiency.power,
  car.decoy_efficiency.efficiency,
  multiply = 0.5
)

## Effects for experiment 3

if (reportCumulatedAttractionEffects) results <- add.mean(
  results,
#  'Bets, cumulated attraction score',
  'Our study, score analysis',
  bet.attraction.scores,
  percent_output = T,
  multiply = 1.0
)

if (reportAverageAttractionEffects) results <- add.mean(
  results,
  'Bets, average attraction',
  bet.attraction.scores,
  percent_output = T,
  multiply = 0.5
)

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  #'Bets, cumulated attraction prop',
  'Our study, proportion analysis',
  bet.decoy_prize.prize,
  bet.decoy_prize.probability,
  bet.decoy_probability.prize,
  bet.decoy_probability.probability,
  multiply = 1.0
)

if (reportCumulatedAttractionEffects) results <- add.prop.diff(
  results,
  'Wedell, proportion analysis',
  wedell.decoy_prize.prize,
  wedell.decoy_prize.probability,
  wedell.decoy_probability.prize,
  wedell.decoy_probability.probability,
  multiply = 1.0
)

results <- add.mean(
  results,
  'Bets, within-pair consistency',
  bet.strategy.scores,
  percent_output = T,
  multiply = 1
)

#
# 4. Derive effect types from labels (used to attribute colors in the plotting function)
#

results$type <- factor(rep('Other', nrow(results)), ordered = TRUE, levels = c(
  'Simple attraction effect',
  'Cumulated attraction effect',
  'Average attraction effect',
  'Other'
))
results[grepl("decoy on ", results$label),]$type <- 'Simple attraction effect'
if (reportCumulatedAttractionEffects)
  results[grepl("cumulated", results$label),]$type <- 'Cumulated attraction effect'
if (reportAverageAttractionEffects)
  results[grepl("average ", results$label),]$type <- 'Average attraction effect'
palette <- c("#888888", "#EE4444", "#000000", "#4466FF")
results$type <- as.factor(results$type)

#
# 5. Plot all effects and their confidence intervals
#

# Choose which effects to plot
rows.to.plot <- 1:(nrow(results)-1) # plot all but the within-pair consistency score
results.to.plot <- results[rows.to.plot,]

# Simplify the ggplot visual theme
theme_set(theme_bw() + theme(
  axis.title = element_blank(),
  axis.text.y = element_blank(),
  axis.ticks = element_blank(),
  panel.grid.major.y = element_blank(),
  panel.grid.minor.y = element_blank(),
  panel.grid.major.x = element_line(color = "#000000", size = 0.05),
  panel.grid.minor.x = element_line(color = "#000000", size = 0.05),
  panel.border = element_blank(),
  legend.key.size = unit(5,"mm"), 
  plot.margin=unit(c(0.2, 0.2, 0.2, 0.2),"cm"),
  text = element_text(size=17)))

# Plot all confidence intervals
p <- ggplot(data = results.to.plot, aes(x = rev(rows.to.plot), y = point, label=label, col=type)) +
  scale_color_manual(values=palette) +
  geom_pointrange(aes(ymin=ci.lower, ymax=ci.upper), size=0.9) +
  geom_point(size=0.9*5, colour="#ffffff", pch=21) +
  geom_text(y=plotRange[1], hjust=0, size=5.0) +
  geom_abline(intercept = 0, slope = 0, lty = 3, size=0.8) +
  scale_y_continuous(limits = plotRange, labels = scales::percent, breaks=seq(-0.2, 0.6, 0.2)) +
  coord_flip()

print(p)
